@@ -26,6 +26,9 @@ class MkSShellDock;
 class MkSShell : public QObject, public BasePlugin
 {
     Q_OBJECT
+#if QT_VERSION >= 0x050000
+    Q_PLUGIN_METADATA( IID "org.monkeystudio.MonkeyStudio.BasePlugin/1.0" /*FILE PLUGIN_JSON*/ )
+#endif
     Q_INTERFACES( BasePlugin )
     
 protected:  
