@@ -24,6 +24,9 @@
 class ProjectHeaders : public QObject, public BasePlugin
 {
     Q_OBJECT
+#if QT_VERSION >= 0x050000
+    Q_PLUGIN_METADATA( IID "org.monkeystudio.MonkeyStudio.BasePlugin/1.0" /*FILE PLUGIN_JSON*/ )
+#endif
     Q_INTERFACES( BasePlugin )
 
 protected:  
