@@ -24,6 +24,9 @@
 class GNUMake : public QObject, public CLIToolPlugin
 {
     Q_OBJECT
+#if QT_VERSION >= 0x050000
+    Q_PLUGIN_METADATA( IID "org.monkeystudio.MonkeyStudio.CLIToolPlugin/1.0" /*FILE PLUGIN_JSON*/ )
+#endif
     Q_INTERFACES( BasePlugin CLIToolPlugin )
 
 protected:
