@@ -688,9 +688,9 @@ QList<QByteArray> QMakeProjectItem::makefileRules( const QString& filePath ) con
     return rules.values();
 }
 
-QFileInfoList QMakeProjectItem::makefiles() const
+QFileInfoList QMakeProjectItem::makefiles( const QString& directory ) const
 {
-    QDir dir( path() );
+    QDir dir( directory );
     dir.refresh();
     return pMonkeyStudio::getFiles( dir, QStringList( "*Makefile*" ), false );
 }
@@ -805,9 +805,16 @@ QString QMakeProjectItem::defaultActionTypeToText( QMakeProjectItem::DefaultActi
     return actionTypeToText( QMakeProjectItem::ActionType( type ) );
 }
 
+void QMakeProjectItem::executeCommand( const QString& name )
+{
+    mLastCommand = command( name );
+    XUPProjectItem::executeCommand( name );
+}
+
 void QMakeProjectItem::installCommandsV2()
 {
-    const QString suffix = QFileInfo( fileName() ).suffix().toLower();
+    const QFileInfo fileInfo( fileName() );
+    const QString suffix = fileInfo.suffix().toLower();
     
     // Only call qmake and generate commands for true projects, and not include project files
     if ( suffix != "pro" ) {
@@ -827,12 +834,18 @@ void QMakeProjectItem::installCommandsV2()
     if ( version.isValid() ) {
         pCommand cmd;
         
+        QString workingDirectory = "$cpp$";
+        
+        if ( pMonkeyStudio::isShadowBuildActivated() ) {
+            workingDirectory = shadowBuildPath();
+        }
+        
         // qmake command
         cmd = pCommand();
         cmd.setName( defaultActionTypeToString( QMakeProjectItem::QMake ) );
         cmd.setText( defaultActionTypeToText( QMakeProjectItem::QMake ) );
         cmd.setCommand( QString( "%1 %2 $cp$" ).arg( version.qmake() ).arg( version.qmakeParameters() ) );
-        cmd.setWorkingDirectory( "$cpp$" );
+        cmd.setWorkingDirectory( workingDirectory );
         cmd.setProject( this );
         cmd.setSkipOnError( false );
         cmd.addParser( "QMake" );
@@ -872,12 +885,12 @@ void QMakeProjectItem::installCommandsV2()
     }
     
     builderCommand.setProject( this );
-    builderCommand.setWorkingDirectory( path() );
+    builderCommand.setWorkingDirectory( pMonkeyStudio::isShadowBuildActivated() ? shadowBuildPath() : path() );
     builderCommand.setSkipOnError( false );
     
-    QDir dir( path() );
+    QDir dir( builderCommand.workingDirectory() );
     const pCommand makeCommand = builderCommand;
-    const QFileInfoList files = makefiles();
+    const QFileInfoList files = makefiles( dir.path() );
     
     // call qmake to generate makefiles
     if ( files.isEmpty() ) {
@@ -1398,6 +1411,16 @@ CLIToolPlugin* QMakeProjectItem::builder() const
     return MonkeyCore::pluginsManager()->plugin<CLIToolPlugin*>( PluginsManager::stAll, name );
 }
 
+QString QMakeProjectItem::shadowBuildPath() const
+{
+    const XUPProjectItem* tlp = topLevelProject();
+    return pMonkeyStudio::shadowBuildDirectory( // shadow build root path
+        QString( "%1/%2" )
+            .arg( QFileInfo( tlp->fileName() ).baseName() )  // project root folder
+            .arg( path().remove( 0, tlp->path().length() ) ) // project/subproject walk tree path
+    );
+}
+
 void QMakeProjectItem::projectCustomActionTriggered()
 {
     QAction* action = qobject_cast<QAction*>( sender() );
@@ -1407,7 +1430,6 @@ void QMakeProjectItem::projectCustomActionTriggered()
     }
     
     const pCommand cmd = command( action );
-    QDir dir( path() );
     
     switch ( stringToActionType( cmd.name() ) ) {
         case QMakeProjectItem::QMake:
@@ -1443,7 +1465,7 @@ void QMakeProjectItem::projectCustomActionTriggered()
             break;
         }
         default: {
-            const QFileInfoList files = makefiles();
+            const QFileInfoList files = makefiles( pMonkeyStudio::isShadowBuildActivated() ? shadowBuildPath() : path() );
             
             if ( files.isEmpty() ) {
                 executeCommand( defaultActionTypeToString( QMakeProjectItem::QMake ) );
@@ -1461,14 +1483,22 @@ void QMakeProjectItem::consoleManager_commandFinished( const pCommand& cmd, int
     Q_UNUSED( exitCode );
     Q_UNUSED( exitStatus );
     
-    if ( stringToActionType( cmd.name() ) != QMakeProjectItem::QMakeFlag ) {
+    if ( cmd.project() != this || cmd.project() != MonkeyCore::projectsManager()->currentProject() ) {
         return;
     }
     
-    if ( cmd.project() != this || cmd.project() != MonkeyCore::projectsManager()->currentProject() ) {
+    if ( stringToActionType( cmd.name() ) != QMakeProjectItem::QMakeFlag ) {
+        mLastCommand = pCommand();
         return;
     }
     
+    if ( exitStatus == QProcess::CrashExit || exitCode != 0 ) {
+        if ( mLastCommand.name() == cmd.name() ) {
+            mLastCommand = pCommand();
+            return;
+        }
+    }
+    
     uninstallCommands();
     installCommands();
 }
